@@ -115,6 +115,7 @@ gst_dvd_read_src_init (GstDvdReadSrc * src)
   src->dvd_title = NULL;
 
   src->location = g_strdup ("/dev/dvd");
+  src->first_seek = TRUE;
   src->new_seek = TRUE;
   src->new_cell = TRUE;
   src->change_cell = FALSE;
@@ -219,6 +220,8 @@ gst_dvd_read_src_start (GstBaseSrc * basesrc)
   src->new_seek = FALSE;
   src->change_cell = TRUE;
 
+  src->first_seek = TRUE;
+
   return TRUE;
 
   /* ERRORS */
@@ -714,7 +717,8 @@ gst_dvd_read_src_get_sector_from_time (GstDvdReadSrc * src, GstClockTime ts)
   if (src->vts_tmapt == NULL || src->vts_tmapt->nr_of_tmaps < src->ttn)
     return -1;
 
-  sector = 0;
+  sector = src->vts_tmapt->tmap[src->ttn - 1].map_ent[0] & 0x7fffffff;
+
   for (j = 0; j < src->vts_tmapt->tmap[src->ttn - 1].nr_of_entries; ++j) {
     GstClockTime entry_time;
 
@@ -1020,7 +1024,7 @@ gst_dvd_read_src_set_property (GObject * object, guint prop_id,
       if (started) {
         g_warning ("%s: property '%s' needs to be set before the device is "
             "opened", GST_ELEMENT_NAME (src), pspec->name);
-        break;;
+        break;
       }
 
       g_free (src->location);
@@ -1239,6 +1243,13 @@ gst_dvd_read_src_do_seek (GstBaseSrc * basesrc, GstSegment * s)
   GST_DEBUG_OBJECT (src, "Seeking to %s: %12" G_GINT64_FORMAT,
       gst_format_get_name (s->format), s->position);
 
+  /* Ignore the first seek to 0, as it breaks starting playback
+   * from another chapter by seeking back to sector 0 */
+  if (src->first_seek && s->format == GST_FORMAT_BYTES && s->start == 0) {
+    src->first_seek = FALSE;
+    return TRUE;
+  }
+
   if (s->format == sector_format || s->format == GST_FORMAT_BYTES
       || s->format == GST_FORMAT_TIME) {
     guint old;
