@@ -51,7 +51,6 @@ struct _GstX264Enc
   x264_t *x264enc;
   x264_param_t x264param;
   gint current_byte_stream;
-  gint64 ts_offset;
 
   /* List of frame/buffer mapping structs for
    * pending frames */
@@ -97,6 +96,7 @@ struct _GstX264Enc
   GString *tunings;
   GString *option_string_prop; /* option-string property */
   GString *option_string; /* used by set prop */
+  gint frame_packing;
 
   /* input description */
   GstVideoCodecState *input_state;
