@@ -1,5 +1,6 @@
 /* GStreamer
  * Copyright (C) <2005,2006> Wim Taymans <wim@fluendo.com>
+ *               <2013> Wim Taymans <wim.taymans@gmail.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -13,8 +14,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 /*
  * Unless otherwise indicated, Source Code is licensed under MIT license.
@@ -46,8 +47,6 @@
  * @see_also: GstRtspSrc
  *
  * A simple RTP session manager used internally by rtspsrc.
- *
- * Last reviewed on 2006-06-20 (0.10.4)
  */
 
 /* #define HAVE_RTCP */
@@ -251,6 +250,16 @@ create_session (GstRDTManager * rdtmanager, gint id)
   return sess;
 }
 
+static gboolean
+forward_sticky_events (GstPad * pad, GstEvent ** event, gpointer user_data)
+{
+  GstPad *srcpad = GST_PAD_CAST (user_data);
+
+  gst_pad_push_event (srcpad, gst_event_ref (*event));
+
+  return TRUE;
+}
+
 static gboolean
 activate_session (GstRDTManager * rdtmanager, GstRDTManagerSession * session,
     guint32 ssrc, guint8 pt)
@@ -306,6 +315,8 @@ activate_session (GstRDTManager * rdtmanager, GstRDTManagerSession * session,
 
   gst_pad_set_active (session->recv_rtp_src, TRUE);
 
+  gst_pad_sticky_events_foreach (session->recv_rtp_sink, forward_sticky_events,
+      session->recv_rtp_src);
   gst_pad_set_caps (session->recv_rtp_src, caps);
   gst_caps_unref (caps);
 
@@ -519,7 +530,7 @@ gst_rdt_manager_class_init (GstRDTManagerClass * g_class)
   gst_element_class_set_static_metadata (gstelement_class, "RTP Decoder",
       "Codec/Parser/Network",
       "Accepts raw RTP and RTCP packets and sends them forward",
-      "Wim Taymans <wim@fluendo.com>");
+      "Wim Taymans <wim.taymans@gmail.com>");
 
   GST_DEBUG_CATEGORY_INIT (rdtmanager_debug, "rdtmanager", 0, "RTP decoder");
 }
@@ -541,6 +552,7 @@ gst_rdt_manager_finalize (GObject * object)
 
   g_slist_foreach (rdtmanager->sessions, (GFunc) free_session, NULL);
   g_slist_free (rdtmanager->sessions);
+  g_clear_object (&rdtmanager->provided_clock);
 
   G_OBJECT_CLASS (parent_class)->finalize (object);
 }
