@@ -23,6 +23,7 @@
 
 #include <gst/gst.h>
 #include <gst/base/gstadapter.h>
+#include <gst/base/gstflowcombiner.h>
 #include <gst/pbutils/descriptions.h>
 
 G_BEGIN_DECLS
@@ -91,6 +92,8 @@ struct _GstRMDemux {
   GstAdapter *adapter;
   gboolean have_pads;
 
+  GstFlowCombiner *flowcombiner;
+
   guint32 timescale;
   guint64 duration;
   guint32 avg_packet_size;
